/*
 *   Copyright (C) 2010 Alexey Noskov <alexey.noskov@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License or (at your option) version 3 or any later version
 *   accepted by the membership of KDE e.V. (or its successor approved
 *   by the membership of KDE e.V.), which shall act as a proxy
 *   defined in Section 14 of version 3 of the license.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DATETIME_PARSER_H
#define DATETIME_PARSER_H

#include "datetime_range.h"

#include <QMap>

class DateTimeParser {
public:
    DateTimeParser();
    
    KDateTime parse( const QString & s );
    DateTimeRange parseRange( const QString & s );
    
    void addTimeFormat( const QString & s );
    void addDateFormat( const QString & s );
    
private:
    
    typedef QMap< QString, QRegExp > FormatMap;
    
private:
    
    QString parseElement( const QString & s, DateTimeRange & range, DateTimeRange::Elements elems, const QDate & defaultDate = QDate(), const QTime & defaultTime = QTime() );

private:

    FormatMap timeFormats;
    FormatMap dateFormats;
};

#endif
